/*
 * gtktube: a gtk frontend for youtube like services
 * Copyright (C) 2009 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */



#ifndef __UTILS__H
#define __UTILS__H

#include "config.h"

#include <glib.h>


/*
 * Some helpes routine to debug, trace the program
 */
#if defined(__GNUC__)
# define GCC_ATTRIBUTE_PRINTF(x,y) __attribute__((__format__(__printf__,x,y)))
# define GCC_ATTRIBUTE_NORETURN __attribute__ ((noreturn))
#else
# define GCC_ATTRIBUTE_PRINTF(x,y) 
# define GCC_ATTRIBUTE_NORETURN
#endif

#if ENABLE_DEBUG_TRACE
# define trace(fmt, args...) real_trace(__PRETTY_FUNCTION__, fmt, ## args)
# define wtrace(buf, count) write(2,buf,count)
  void real_trace(const char *fname, const char *fmt, ... ) GCC_ATTRIBUTE_PRINTF(2,3);
#else
# define trace(fmt, args...) do { } while(0)
# define wtrace(buf,count) do { } while(0)
#endif

#if ENABLE_DEBUG
# define debug(fmt, args...) real_debug(fmt, ## args)
# define wdebug(buf, count) write(2,buf,count)
  void real_debug(const char *fmt, ... ) GCC_ATTRIBUTE_PRINTF(1,2);
#else
# define debug(fmt, args...) do { } while(0)
# define wdebug(buf, count) do { } while(0)
#endif

void error(const char *fmt, ... ) GCC_ATTRIBUTE_PRINTF(1,2);
void die(const char *fmt, ... ) GCC_ATTRIBUTE_PRINTF(1,2) GCC_ATTRIBUTE_NORETURN;
void die_with_errno(int err, const char *fmt, ... ) GCC_ATTRIBUTE_PRINTF(2,3) GCC_ATTRIBUTE_NORETURN;

#define KiBYTES (1024ULL)
#define MiBYTES (1024ULL*KiBYTES)
#define GiBYTES (1024ULL*MiBYTES)
#define TiBYTES (1024ULL*GiBYTES)

#define KBYTES (1000ULL)
#define MBYTES (1000ULL*KBYTES)
#define GBYTES (1000ULL*MBYTES)
#define TBYTES (1000ULL*GBYTES)


char *size_to_string(const char *prefix, unsigned long long  size);
char *network_size_to_string(const char *prefix, unsigned long long size, const char *suffix);
char *time_us_to_string(unsigned long long time);

char *regex_match_simple(const char *text, const char *regex);

#endif


